/* GXmlListNamespaces.c generated by valac 0.34.6, the Vala compiler
 * generated from GXmlListNamespaces.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 0; tab-width: 2 -*- */
/* GXmlListNamespaces.vala
 *
 * Copyright (C) 2015  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <gee.h>
#include <libxml/tree.h>
#include <stdlib.h>
#include <string.h>


#define GXML_TYPE_GLIST_NAMESPACES (gxml_glist_namespaces_get_type ())
#define GXML_GLIST_NAMESPACES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GLIST_NAMESPACES, GXmlGListNamespaces))
#define GXML_GLIST_NAMESPACES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GLIST_NAMESPACES, GXmlGListNamespacesClass))
#define GXML_IS_GLIST_NAMESPACES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GLIST_NAMESPACES))
#define GXML_IS_GLIST_NAMESPACES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GLIST_NAMESPACES))
#define GXML_GLIST_NAMESPACES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GLIST_NAMESPACES, GXmlGListNamespacesClass))

typedef struct _GXmlGListNamespaces GXmlGListNamespaces;
typedef struct _GXmlGListNamespacesClass GXmlGListNamespacesClass;
typedef struct _GXmlGListNamespacesPrivate GXmlGListNamespacesPrivate;

#define GXML_TYPE_GNODE (gxml_gnode_get_type ())
#define GXML_GNODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GNODE, GXmlGNode))
#define GXML_GNODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GNODE, GXmlGNodeClass))
#define GXML_IS_GNODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GNODE))
#define GXML_IS_GNODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GNODE))
#define GXML_GNODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GNODE, GXmlGNodeClass))

typedef struct _GXmlGNode GXmlGNode;
typedef struct _GXmlGNodeClass GXmlGNodeClass;

#define GXML_TYPE_GDOCUMENT (gxml_gdocument_get_type ())
#define GXML_GDOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOCUMENT, GXmlGDocument))
#define GXML_GDOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOCUMENT, GXmlGDocumentClass))
#define GXML_IS_GDOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOCUMENT))
#define GXML_IS_GDOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOCUMENT))
#define GXML_GDOCUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOCUMENT, GXmlGDocumentClass))

typedef struct _GXmlGDocument GXmlGDocument;
typedef struct _GXmlGDocumentClass GXmlGDocumentClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define GXML_TYPE_NAMESPACE (gxml_namespace_get_type ())
#define GXML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE, GXmlNamespace))
#define GXML_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE))
#define GXML_NAMESPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NAMESPACE, GXmlNamespaceIface))

typedef struct _GXmlNamespace GXmlNamespace;
typedef struct _GXmlNamespaceIface GXmlNamespaceIface;

#define GXML_TYPE_GNAMESPACE (gxml_gnamespace_get_type ())
#define GXML_GNAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GNAMESPACE, GXmlGNamespace))
#define GXML_GNAMESPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GNAMESPACE, GXmlGNamespaceClass))
#define GXML_IS_GNAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GNAMESPACE))
#define GXML_IS_GNAMESPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GNAMESPACE))
#define GXML_GNAMESPACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GNAMESPACE, GXmlGNamespaceClass))

typedef struct _GXmlGNamespace GXmlGNamespace;
typedef struct _GXmlGNamespaceClass GXmlGNamespaceClass;

#define GXML_GLIST_NAMESPACES_TYPE_ITERATOR (gxml_glist_namespaces_iterator_get_type ())
#define GXML_GLIST_NAMESPACES_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_GLIST_NAMESPACES_TYPE_ITERATOR, GXmlGListNamespacesIterator))
#define GXML_GLIST_NAMESPACES_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_GLIST_NAMESPACES_TYPE_ITERATOR, GXmlGListNamespacesIteratorClass))
#define GXML_GLIST_NAMESPACES_IS_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_GLIST_NAMESPACES_TYPE_ITERATOR))
#define GXML_GLIST_NAMESPACES_IS_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_GLIST_NAMESPACES_TYPE_ITERATOR))
#define GXML_GLIST_NAMESPACES_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_GLIST_NAMESPACES_TYPE_ITERATOR, GXmlGListNamespacesIteratorClass))

typedef struct _GXmlGListNamespacesIterator GXmlGListNamespacesIterator;
typedef struct _GXmlGListNamespacesIteratorClass GXmlGListNamespacesIteratorClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _GXmlGListNamespacesIteratorPrivate GXmlGListNamespacesIteratorPrivate;

struct _GXmlGListNamespaces {
	GeeAbstractList parent_instance;
	GXmlGListNamespacesPrivate * priv;
};

struct _GXmlGListNamespacesClass {
	GeeAbstractListClass parent_class;
};

struct _GXmlGListNamespacesPrivate {
	GXmlGDocument* _doc;
	xmlNode* _node;
};

struct _GXmlNamespaceIface {
	GTypeInterface parent_iface;
	gchar* (*get_uri) (GXmlNamespace* self);
	gchar* (*get_prefix) (GXmlNamespace* self);
};

struct _GXmlGListNamespacesIterator {
	GObject parent_instance;
	GXmlGListNamespacesIteratorPrivate * priv;
};

struct _GXmlGListNamespacesIteratorClass {
	GObjectClass parent_class;
};

struct _GXmlGListNamespacesIteratorPrivate {
	xmlNode* _node;
	xmlNs* _current;
	gint i;
};


static gpointer gxml_glist_namespaces_parent_class = NULL;
static gpointer gxml_glist_namespaces_iterator_parent_class = NULL;
static GeeTraversableIface* gxml_glist_namespaces_iterator_gee_traversable_parent_iface = NULL;
static GeeIteratorIface* gxml_glist_namespaces_iterator_gee_iterator_parent_iface = NULL;
static GeeListIteratorIface* gxml_glist_namespaces_iterator_gee_list_iterator_parent_iface = NULL;

GType gxml_glist_namespaces_get_type (void) G_GNUC_CONST;
GType gxml_gnode_get_type (void) G_GNUC_CONST;
GType gxml_gdocument_get_type (void) G_GNUC_CONST;
#define GXML_GLIST_NAMESPACES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GXML_TYPE_GLIST_NAMESPACES, GXmlGListNamespacesPrivate))
enum  {
	GXML_GLIST_NAMESPACES_DUMMY_PROPERTY,
	GXML_GLIST_NAMESPACES_READ_ONLY,
	GXML_GLIST_NAMESPACES_SIZE
};
GXmlGListNamespaces* gxml_glist_namespaces_new (GXmlGDocument* doc, xmlNode* node);
GXmlGListNamespaces* gxml_glist_namespaces_construct (GType object_type, GXmlGDocument* doc, xmlNode* node);
GType gxml_namespace_get_type (void) G_GNUC_CONST;
static GXmlNamespace* gxml_glist_namespaces_real_get (GeeAbstractList* base, gint index);
GXmlGNamespace* gxml_gnamespace_new (xmlNs* ns);
GXmlGNamespace* gxml_gnamespace_construct (GType object_type, xmlNs* ns);
GType gxml_gnamespace_get_type (void) G_GNUC_CONST;
static gint gxml_glist_namespaces_real_index_of (GeeAbstractList* base, GXmlNamespace* item);
xmlNs* gxml_gnamespace_get_internal_ns (GXmlGNamespace* self);
static void gxml_glist_namespaces_real_insert (GeeAbstractList* base, gint index, GXmlNamespace* item);
static GeeListIterator* gxml_glist_namespaces_real_list_iterator (GeeAbstractList* base);
GXmlGListNamespacesIterator* gxml_glist_namespaces_iterator_new (xmlNode* node);
GXmlGListNamespacesIterator* gxml_glist_namespaces_iterator_construct (GType object_type, xmlNode* node);
GType gxml_glist_namespaces_iterator_get_type (void) G_GNUC_CONST;
static GXmlNamespace* gxml_glist_namespaces_real_remove_at (GeeAbstractList* base, gint index);
static void gxml_glist_namespaces_real_set (GeeAbstractList* base, gint index, GXmlNamespace* item);
static GeeList* gxml_glist_namespaces_real_slice (GeeAbstractList* base, gint start, gint stop);
static gboolean gxml_glist_namespaces_real_add (GeeAbstractCollection* base, GXmlNamespace* item);
gchar* gxml_namespace_get_uri (GXmlNamespace* self);
gchar* gxml_namespace_get_prefix (GXmlNamespace* self);
static void gxml_glist_namespaces_real_clear (GeeAbstractCollection* base);
static gboolean gxml_glist_namespaces_real_contains (GeeAbstractCollection* base, GXmlNamespace* item);
static GeeIterator* gxml_glist_namespaces_real_iterator (GeeAbstractCollection* base);
static gboolean gxml_glist_namespaces_real_remove (GeeAbstractCollection* base, GXmlNamespace* item);
#define GXML_GLIST_NAMESPACES_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GXML_GLIST_NAMESPACES_TYPE_ITERATOR, GXmlGListNamespacesIteratorPrivate))
enum  {
	GXML_GLIST_NAMESPACES_ITERATOR_DUMMY_PROPERTY,
	GXML_GLIST_NAMESPACES_ITERATOR_READ_ONLY,
	GXML_GLIST_NAMESPACES_ITERATOR_VALID
};
static void gxml_glist_namespaces_iterator_real_add (GeeListIterator* base, GXmlNamespace* item);
static gint gxml_glist_namespaces_iterator_real_index (GeeListIterator* base);
static void gxml_glist_namespaces_iterator_real_set (GeeListIterator* base, GXmlNamespace* item);
static GXmlNamespace* gxml_glist_namespaces_iterator_real_get (GeeIterator* base);
static gboolean gxml_glist_namespaces_iterator_real_has_next (GeeIterator* base);
static gboolean gxml_glist_namespaces_iterator_real_next (GeeIterator* base);
static void gxml_glist_namespaces_iterator_real_remove (GeeIterator* base);
static gboolean gxml_glist_namespaces_iterator_real_foreach (GeeTraversable* base, GeeForallFunc f, void* f_target);
static void gxml_glist_namespaces_iterator_finalize (GObject* obj);
static void _vala_gxml_glist_namespaces_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void gxml_glist_namespaces_finalize (GObject* obj);
static void _vala_gxml_glist_namespaces_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);


static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


GXmlGListNamespaces* gxml_glist_namespaces_construct (GType object_type, GXmlGDocument* doc, xmlNode* node) {
	GXmlGListNamespaces * self = NULL;
	xmlNode* _tmp0_ = NULL;
	GXmlGDocument* _tmp1_ = NULL;
	GXmlGDocument* _tmp2_ = NULL;
	g_return_val_if_fail (doc != NULL, NULL);
	self = (GXmlGListNamespaces*) gee_abstract_list_construct (object_type, GXML_TYPE_NAMESPACE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
	_tmp0_ = node;
	self->priv->_node = _tmp0_;
	_tmp1_ = doc;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (self->priv->_doc);
	self->priv->_doc = _tmp2_;
	return self;
}


GXmlGListNamespaces* gxml_glist_namespaces_new (GXmlGDocument* doc, xmlNode* node) {
	return gxml_glist_namespaces_construct (GXML_TYPE_GLIST_NAMESPACES, doc, node);
}


static GXmlNamespace* gxml_glist_namespaces_real_get (GeeAbstractList* base, gint index) {
	GXmlGListNamespaces * self;
	GXmlNamespace* result = NULL;
	GXmlNamespace* nullns = NULL;
	xmlNode* _tmp0_ = NULL;
	xmlNs* ns = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNs* _tmp2_ = NULL;
	gint i = 0;
	self = (GXmlGListNamespaces*) base;
	nullns = NULL;
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		result = nullns;
		return result;
	}
	_tmp1_ = self->priv->_node;
	_tmp2_ = _tmp1_->nsDef;
	ns = _tmp2_;
	i = 0;
	while (TRUE) {
		xmlNs* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		gint _tmp5_ = 0;
		xmlNs* _tmp8_ = NULL;
		xmlNs* _tmp9_ = NULL;
		gint _tmp10_ = 0;
		_tmp3_ = ns;
		if (!(_tmp3_ != NULL)) {
			break;
		}
		_tmp4_ = i;
		_tmp5_ = index;
		if (_tmp4_ == _tmp5_) {
			xmlNs* _tmp6_ = NULL;
			GXmlGNamespace* _tmp7_ = NULL;
			_tmp6_ = ns;
			_tmp7_ = gxml_gnamespace_new (_tmp6_);
			result = (GXmlNamespace*) _tmp7_;
			_g_object_unref0 (nullns);
			return result;
		}
		_tmp8_ = ns;
		_tmp9_ = _tmp8_->next;
		ns = _tmp9_;
		_tmp10_ = i;
		i = _tmp10_ + 1;
	}
	result = nullns;
	return result;
}


static gint gxml_glist_namespaces_real_index_of (GeeAbstractList* base, GXmlNamespace* item) {
	GXmlGListNamespaces * self;
	gint result = 0;
	xmlNode* _tmp0_ = NULL;
	GXmlNamespace* _tmp1_ = NULL;
	xmlNs* ns = NULL;
	xmlNode* _tmp2_ = NULL;
	xmlNs* _tmp3_ = NULL;
	gint i = 0;
	self = (GXmlGListNamespaces*) base;
	g_return_val_if_fail (item != NULL, 0);
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		result = -1;
		return result;
	}
	_tmp1_ = item;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GXML_TYPE_GNAMESPACE)) {
		result = -1;
		return result;
	}
	_tmp2_ = self->priv->_node;
	_tmp3_ = _tmp2_->nsDef;
	ns = _tmp3_;
	i = 0;
	while (TRUE) {
		xmlNs* _tmp4_ = NULL;
		GXmlNamespace* _tmp5_ = NULL;
		xmlNs* _tmp6_ = NULL;
		xmlNs* _tmp7_ = NULL;
		xmlNs* _tmp8_ = NULL;
		xmlNs* _tmp9_ = NULL;
		gint _tmp10_ = 0;
		_tmp4_ = ns;
		if (!(_tmp4_ != NULL)) {
			break;
		}
		_tmp5_ = item;
		_tmp6_ = gxml_gnamespace_get_internal_ns (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GXML_TYPE_GNAMESPACE, GXmlGNamespace));
		_tmp7_ = ns;
		if (_tmp6_ == _tmp7_) {
			result = i;
			return result;
		}
		_tmp8_ = ns;
		_tmp9_ = _tmp8_->next;
		ns = _tmp9_;
		_tmp10_ = i;
		i = _tmp10_ + 1;
	}
	result = -1;
	return result;
}


static void gxml_glist_namespaces_real_insert (GeeAbstractList* base, gint index, GXmlNamespace* item) {
	GXmlGListNamespaces * self;
	self = (GXmlGListNamespaces*) base;
	g_return_if_fail (item != NULL);
}


static GeeListIterator* gxml_glist_namespaces_real_list_iterator (GeeAbstractList* base) {
	GXmlGListNamespaces * self;
	GeeListIterator* result = NULL;
	xmlNode* _tmp0_ = NULL;
	GXmlGListNamespacesIterator* _tmp1_ = NULL;
	self = (GXmlGListNamespaces*) base;
	_tmp0_ = self->priv->_node;
	_tmp1_ = gxml_glist_namespaces_iterator_new (_tmp0_);
	result = (GeeListIterator*) _tmp1_;
	return result;
}


static GXmlNamespace* gxml_glist_namespaces_real_remove_at (GeeAbstractList* base, gint index) {
	GXmlGListNamespaces * self;
	GXmlNamespace* result = NULL;
	GXmlNamespace* nullns = NULL;
	self = (GXmlGListNamespaces*) base;
	nullns = NULL;
	result = nullns;
	return result;
}


static void gxml_glist_namespaces_real_set (GeeAbstractList* base, gint index, GXmlNamespace* item) {
	GXmlGListNamespaces * self;
	self = (GXmlGListNamespaces*) base;
	g_return_if_fail (item != NULL);
}


static GeeList* gxml_glist_namespaces_real_slice (GeeAbstractList* base, gint start, gint stop) {
	GXmlGListNamespaces * self;
	GeeList* result = NULL;
	GeeArrayList* l = NULL;
	GeeArrayList* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNs* ns = NULL;
	xmlNode* _tmp2_ = NULL;
	xmlNs* _tmp3_ = NULL;
	gint i = 0;
	self = (GXmlGListNamespaces*) base;
	_tmp0_ = gee_array_list_new (GXML_TYPE_NAMESPACE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
	l = _tmp0_;
	_tmp1_ = self->priv->_node;
	if (_tmp1_ == NULL) {
		result = (GeeList*) l;
		return result;
	}
	_tmp2_ = self->priv->_node;
	_tmp3_ = _tmp2_->nsDef;
	ns = _tmp3_;
	i = 0;
	while (TRUE) {
		xmlNs* _tmp4_ = NULL;
		gboolean _tmp5_ = FALSE;
		gint _tmp6_ = 0;
		gint _tmp7_ = 0;
		xmlNs* _tmp14_ = NULL;
		xmlNs* _tmp15_ = NULL;
		gint _tmp16_ = 0;
		_tmp4_ = ns;
		if (!(_tmp4_ != NULL)) {
			break;
		}
		_tmp6_ = i;
		_tmp7_ = start;
		if (_tmp6_ >= _tmp7_) {
			gint _tmp8_ = 0;
			gint _tmp9_ = 0;
			_tmp8_ = i;
			_tmp9_ = stop;
			_tmp5_ = _tmp8_ <= _tmp9_;
		} else {
			_tmp5_ = FALSE;
		}
		if (_tmp5_) {
			GeeArrayList* _tmp10_ = NULL;
			xmlNs* _tmp11_ = NULL;
			GXmlGNamespace* _tmp12_ = NULL;
			GXmlGNamespace* _tmp13_ = NULL;
			_tmp10_ = l;
			_tmp11_ = ns;
			_tmp12_ = gxml_gnamespace_new (_tmp11_);
			_tmp13_ = _tmp12_;
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp10_, (GXmlNamespace*) _tmp13_);
			_g_object_unref0 (_tmp13_);
		}
		_tmp14_ = ns;
		_tmp15_ = _tmp14_->next;
		ns = _tmp15_;
		_tmp16_ = i;
		i = _tmp16_ + 1;
	}
	result = (GeeList*) l;
	return result;
}


static gboolean gxml_glist_namespaces_real_add (GeeAbstractCollection* base, GXmlNamespace* item) {
	GXmlGListNamespaces * self;
	gboolean result = FALSE;
	GXmlNamespace* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNode* _tmp2_ = NULL;
	GXmlNamespace* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	GXmlNamespace* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	xmlNs* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	self = (GXmlGListNamespaces*) base;
	g_return_val_if_fail (item != NULL, FALSE);
	_tmp0_ = item;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_NAMESPACE)) {
		result = FALSE;
		return result;
	}
	_tmp1_ = self->priv->_node;
	if (_tmp1_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp2_ = self->priv->_node;
	_tmp3_ = item;
	_tmp4_ = gxml_namespace_get_uri (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GXML_TYPE_NAMESPACE, GXmlNamespace));
	_tmp5_ = _tmp4_;
	_tmp6_ = _tmp5_;
	_tmp7_ = item;
	_tmp8_ = gxml_namespace_get_prefix (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GXML_TYPE_NAMESPACE, GXmlNamespace));
	_tmp9_ = _tmp8_;
	_tmp10_ = _tmp9_;
	_tmp11_ = xmlNewNs (_tmp2_, (xmlChar*) _tmp6_, (xmlChar*) _tmp10_);
	_tmp12_ = _tmp11_ != NULL;
	_g_free0 (_tmp10_);
	_g_free0 (_tmp6_);
	result = _tmp12_;
	return result;
}


static void gxml_glist_namespaces_real_clear (GeeAbstractCollection* base) {
	GXmlGListNamespaces * self;
	self = (GXmlGListNamespaces*) base;
}


static gboolean gxml_glist_namespaces_real_contains (GeeAbstractCollection* base, GXmlNamespace* item) {
	GXmlGListNamespaces * self;
	gboolean result = FALSE;
	GXmlNamespace* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNs* ns = NULL;
	xmlNode* _tmp2_ = NULL;
	xmlNs* _tmp3_ = NULL;
	self = (GXmlGListNamespaces*) base;
	g_return_val_if_fail (item != NULL, FALSE);
	_tmp0_ = item;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_GNAMESPACE)) {
		result = FALSE;
		return result;
	}
	_tmp1_ = self->priv->_node;
	if (_tmp1_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp2_ = self->priv->_node;
	_tmp3_ = _tmp2_->nsDef;
	ns = _tmp3_;
	while (TRUE) {
		xmlNs* _tmp4_ = NULL;
		xmlNs* _tmp5_ = NULL;
		GXmlNamespace* _tmp6_ = NULL;
		xmlNs* _tmp7_ = NULL;
		_tmp4_ = ns;
		if (!(_tmp4_ != NULL)) {
			break;
		}
		_tmp5_ = ns;
		_tmp6_ = item;
		_tmp7_ = gxml_gnamespace_get_internal_ns (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GXML_TYPE_GNAMESPACE, GXmlGNamespace));
		if (_tmp5_ == _tmp7_) {
			result = TRUE;
			return result;
		}
	}
	result = FALSE;
	return result;
}


static GeeIterator* gxml_glist_namespaces_real_iterator (GeeAbstractCollection* base) {
	GXmlGListNamespaces * self;
	GeeIterator* result = NULL;
	xmlNode* _tmp0_ = NULL;
	GXmlGListNamespacesIterator* _tmp1_ = NULL;
	self = (GXmlGListNamespaces*) base;
	_tmp0_ = self->priv->_node;
	_tmp1_ = gxml_glist_namespaces_iterator_new (_tmp0_);
	result = (GeeIterator*) _tmp1_;
	return result;
}


static gboolean gxml_glist_namespaces_real_remove (GeeAbstractCollection* base, GXmlNamespace* item) {
	GXmlGListNamespaces * self;
	gboolean result = FALSE;
	self = (GXmlGListNamespaces*) base;
	g_return_val_if_fail (item != NULL, FALSE);
	result = FALSE;
	return result;
}


static gboolean gxml_glist_namespaces_real_get_read_only (GeeAbstractCollection* base) {
	gboolean result;
	GXmlGListNamespaces* self;
	self = (GXmlGListNamespaces*) base;
	result = FALSE;
	return result;
}


static gint gxml_glist_namespaces_real_get_size (GeeAbstractCollection* base) {
	gint result;
	GXmlGListNamespaces* self;
	xmlNode* _tmp0_ = NULL;
	xmlNs* ns = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNs* _tmp2_ = NULL;
	gint i = 0;
	gint _tmp7_ = 0;
	self = (GXmlGListNamespaces*) base;
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		result = -1;
		return result;
	}
	_tmp1_ = self->priv->_node;
	_tmp2_ = _tmp1_->nsDef;
	ns = _tmp2_;
	i = 0;
	while (TRUE) {
		xmlNs* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		xmlNs* _tmp5_ = NULL;
		xmlNs* _tmp6_ = NULL;
		_tmp3_ = ns;
		if (!(_tmp3_ != NULL)) {
			break;
		}
		_tmp4_ = i;
		i = _tmp4_ + 1;
		_tmp5_ = ns;
		_tmp6_ = _tmp5_->next;
		ns = _tmp6_;
	}
	_tmp7_ = i;
	result = _tmp7_;
	return result;
}


GXmlGListNamespacesIterator* gxml_glist_namespaces_iterator_construct (GType object_type, xmlNode* node) {
	GXmlGListNamespacesIterator * self = NULL;
	xmlNode* _tmp0_ = NULL;
	self = (GXmlGListNamespacesIterator*) g_object_new (object_type, NULL);
	_tmp0_ = node;
	self->priv->_node = _tmp0_;
	return self;
}


GXmlGListNamespacesIterator* gxml_glist_namespaces_iterator_new (xmlNode* node) {
	return gxml_glist_namespaces_iterator_construct (GXML_GLIST_NAMESPACES_TYPE_ITERATOR, node);
}


static void gxml_glist_namespaces_iterator_real_add (GeeListIterator* base, GXmlNamespace* item) {
	GXmlGListNamespacesIterator * self;
	xmlNode* _tmp0_ = NULL;
	GXmlNamespace* _tmp1_ = NULL;
	GXmlNamespace* ns = NULL;
	GXmlNamespace* _tmp2_ = NULL;
	GXmlNamespace* _tmp3_ = NULL;
	xmlNode* _tmp4_ = NULL;
	GXmlNamespace* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	GXmlNamespace* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	self = (GXmlGListNamespacesIterator*) base;
	g_return_if_fail (item != NULL);
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		return;
	}
	_tmp1_ = item;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GXML_TYPE_NAMESPACE)) {
		return;
	}
	_tmp2_ = item;
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GXML_TYPE_NAMESPACE, GXmlNamespace));
	ns = _tmp3_;
	_tmp4_ = self->priv->_node;
	_tmp5_ = ns;
	_tmp6_ = gxml_namespace_get_uri (_tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = _tmp7_;
	_tmp9_ = ns;
	_tmp10_ = gxml_namespace_get_prefix (_tmp9_);
	_tmp11_ = _tmp10_;
	_tmp12_ = _tmp11_;
	xmlNewNs (_tmp4_, (xmlChar*) _tmp8_, (xmlChar*) _tmp12_);
	_g_free0 (_tmp12_);
	_g_free0 (_tmp8_);
	_g_object_unref0 (ns);
}


static gint gxml_glist_namespaces_iterator_real_index (GeeListIterator* base) {
	GXmlGListNamespacesIterator * self;
	gint result = 0;
	gint _tmp0_ = 0;
	self = (GXmlGListNamespacesIterator*) base;
	_tmp0_ = self->priv->i;
	result = _tmp0_;
	return result;
}


static void gxml_glist_namespaces_iterator_real_set (GeeListIterator* base, GXmlNamespace* item) {
	GXmlGListNamespacesIterator * self;
	self = (GXmlGListNamespacesIterator*) base;
	g_return_if_fail (item != NULL);
}


static GXmlNamespace* gxml_glist_namespaces_iterator_real_get (GeeIterator* base) {
	GXmlGListNamespacesIterator * self;
	GXmlNamespace* result = NULL;
	xmlNs* _tmp0_ = NULL;
	GXmlGNamespace* _tmp1_ = NULL;
	self = (GXmlGListNamespacesIterator*) base;
	_tmp0_ = self->priv->_current;
	_tmp1_ = gxml_gnamespace_new (_tmp0_);
	result = (GXmlNamespace*) _tmp1_;
	return result;
}


static gboolean gxml_glist_namespaces_iterator_real_has_next (GeeIterator* base) {
	GXmlGListNamespacesIterator * self;
	gboolean result = FALSE;
	xmlNode* _tmp0_ = NULL;
	xmlNs* _tmp1_ = NULL;
	xmlNs* _tmp2_ = NULL;
	self = (GXmlGListNamespacesIterator*) base;
	_tmp0_ = self->priv->_node;
	_tmp1_ = _tmp0_->nsDef;
	if (_tmp1_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp2_ = self->priv->_current;
	if (_tmp2_ != NULL) {
		xmlNs* _tmp3_ = NULL;
		xmlNs* _tmp4_ = NULL;
		_tmp3_ = self->priv->_current;
		_tmp4_ = _tmp3_->next;
		if (_tmp4_ == NULL) {
			result = FALSE;
			return result;
		}
	}
	result = TRUE;
	return result;
}


static gboolean gxml_glist_namespaces_iterator_real_next (GeeIterator* base) {
	GXmlGListNamespacesIterator * self;
	gboolean result = FALSE;
	xmlNode* _tmp0_ = NULL;
	xmlNs* _tmp1_ = NULL;
	xmlNs* _tmp2_ = NULL;
	xmlNs* _tmp5_ = NULL;
	xmlNs* _tmp6_ = NULL;
	xmlNs* _tmp7_ = NULL;
	xmlNs* _tmp8_ = NULL;
	self = (GXmlGListNamespacesIterator*) base;
	_tmp0_ = self->priv->_node;
	_tmp1_ = _tmp0_->nsDef;
	if (_tmp1_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp2_ = self->priv->_current;
	if (_tmp2_ == NULL) {
		xmlNode* _tmp3_ = NULL;
		xmlNs* _tmp4_ = NULL;
		_tmp3_ = self->priv->_node;
		_tmp4_ = _tmp3_->nsDef;
		self->priv->_current = _tmp4_;
	}
	_tmp5_ = self->priv->_current;
	_tmp6_ = _tmp5_->next;
	if (_tmp6_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp7_ = self->priv->_current;
	_tmp8_ = _tmp7_->next;
	self->priv->_current = _tmp8_;
	result = TRUE;
	return result;
}


static void gxml_glist_namespaces_iterator_real_remove (GeeIterator* base) {
	GXmlGListNamespacesIterator * self;
	self = (GXmlGListNamespacesIterator*) base;
}


static gboolean gxml_glist_namespaces_iterator_real_foreach (GeeTraversable* base, GeeForallFunc f, void* f_target) {
	GXmlGListNamespacesIterator * self;
	gboolean result = FALSE;
	self = (GXmlGListNamespacesIterator*) base;
	while (TRUE) {
		gboolean _tmp0_ = FALSE;
		GeeForallFunc _tmp1_ = NULL;
		void* _tmp1__target = NULL;
		gpointer _tmp2_ = NULL;
		gboolean _tmp3_ = FALSE;
		_tmp0_ = gee_iterator_has_next ((GeeIterator*) self);
		if (!_tmp0_) {
			break;
		}
		gee_iterator_next ((GeeIterator*) self);
		_tmp1_ = f;
		_tmp1__target = f_target;
		_tmp2_ = gee_iterator_get ((GeeIterator*) self);
		_tmp3_ = _tmp1_ ((GXmlNamespace*) _tmp2_, _tmp1__target);
		if (!_tmp3_) {
			result = FALSE;
			return result;
		}
	}
	result = TRUE;
	return result;
}


static gboolean gxml_glist_namespaces_iterator_real_get_read_only (GeeIterator* base) {
	gboolean result;
	GXmlGListNamespacesIterator* self;
	self = (GXmlGListNamespacesIterator*) base;
	result = FALSE;
	return result;
}


static gboolean gxml_glist_namespaces_iterator_real_get_valid (GeeIterator* base) {
	gboolean result;
	GXmlGListNamespacesIterator* self;
	xmlNs* _tmp0_ = NULL;
	self = (GXmlGListNamespacesIterator*) base;
	_tmp0_ = self->priv->_current;
	result = _tmp0_ != NULL;
	return result;
}


static void gxml_glist_namespaces_iterator_class_init (GXmlGListNamespacesIteratorClass * klass) {
	gxml_glist_namespaces_iterator_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (GXmlGListNamespacesIteratorPrivate));
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_glist_namespaces_iterator_get_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_glist_namespaces_iterator_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GLIST_NAMESPACES_ITERATOR_READ_ONLY, g_param_spec_boolean ("read-only", "read-only", "read-only", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GLIST_NAMESPACES_ITERATOR_VALID, g_param_spec_boolean ("valid", "valid", "valid", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
}


static GType gxml_glist_namespaces_iterator_gee_traversable_get_g_type (GXmlGListNamespacesIterator* self) {
	return GXML_TYPE_NAMESPACE;
}


static GBoxedCopyFunc gxml_glist_namespaces_iterator_gee_traversable_get_g_dup_func (GXmlGListNamespacesIterator* self) {
	return g_object_ref;
}


static GDestroyNotify gxml_glist_namespaces_iterator_gee_traversable_get_g_destroy_func (GXmlGListNamespacesIterator* self) {
	return g_object_unref;
}


static void gxml_glist_namespaces_iterator_gee_traversable_interface_init (GeeTraversableIface * iface) {
	gxml_glist_namespaces_iterator_gee_traversable_parent_iface = g_type_interface_peek_parent (iface);
	iface->foreach = (gboolean (*)(GeeTraversable*, GeeForallFunc, void*)) gxml_glist_namespaces_iterator_real_foreach;
	iface->get_g_type = (GType(*)(GeeTraversable*)) gxml_glist_namespaces_iterator_gee_traversable_get_g_type;
	iface->get_g_dup_func = (GBoxedCopyFunc(*)(GeeTraversable*)) gxml_glist_namespaces_iterator_gee_traversable_get_g_dup_func;
	iface->get_g_destroy_func = (GDestroyNotify(*)(GeeTraversable*)) gxml_glist_namespaces_iterator_gee_traversable_get_g_destroy_func;
}


static void gxml_glist_namespaces_iterator_gee_iterator_interface_init (GeeIteratorIface * iface) {
	gxml_glist_namespaces_iterator_gee_iterator_parent_iface = g_type_interface_peek_parent (iface);
	iface->get = (gpointer (*)(GeeIterator*)) gxml_glist_namespaces_iterator_real_get;
	iface->has_next = (gboolean (*)(GeeIterator*)) gxml_glist_namespaces_iterator_real_has_next;
	iface->next = (gboolean (*)(GeeIterator*)) gxml_glist_namespaces_iterator_real_next;
	iface->remove = (void (*)(GeeIterator*)) gxml_glist_namespaces_iterator_real_remove;
	iface->get_read_only = gxml_glist_namespaces_iterator_real_get_read_only;
	iface->get_valid = gxml_glist_namespaces_iterator_real_get_valid;
}


static void gxml_glist_namespaces_iterator_gee_list_iterator_interface_init (GeeListIteratorIface * iface) {
	gxml_glist_namespaces_iterator_gee_list_iterator_parent_iface = g_type_interface_peek_parent (iface);
	iface->add = (void (*)(GeeListIterator*, gconstpointer)) gxml_glist_namespaces_iterator_real_add;
	iface->index = (gint (*)(GeeListIterator*)) gxml_glist_namespaces_iterator_real_index;
	iface->set = (void (*)(GeeListIterator*, gconstpointer)) gxml_glist_namespaces_iterator_real_set;
}


static void gxml_glist_namespaces_iterator_instance_init (GXmlGListNamespacesIterator * self) {
	self->priv = GXML_GLIST_NAMESPACES_ITERATOR_GET_PRIVATE (self);
	self->priv->i = -1;
}


static void gxml_glist_namespaces_iterator_finalize (GObject* obj) {
	GXmlGListNamespacesIterator * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_GLIST_NAMESPACES_TYPE_ITERATOR, GXmlGListNamespacesIterator);
	G_OBJECT_CLASS (gxml_glist_namespaces_iterator_parent_class)->finalize (obj);
}


GType gxml_glist_namespaces_iterator_get_type (void) {
	static volatile gsize gxml_glist_namespaces_iterator_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_glist_namespaces_iterator_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGListNamespacesIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_glist_namespaces_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGListNamespacesIterator), 0, (GInstanceInitFunc) gxml_glist_namespaces_iterator_instance_init, NULL };
		static const GInterfaceInfo gee_traversable_info = { (GInterfaceInitFunc) gxml_glist_namespaces_iterator_gee_traversable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gee_iterator_info = { (GInterfaceInitFunc) gxml_glist_namespaces_iterator_gee_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gee_list_iterator_info = { (GInterfaceInitFunc) gxml_glist_namespaces_iterator_gee_list_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_glist_namespaces_iterator_type_id;
		gxml_glist_namespaces_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GXmlGListNamespacesIterator", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_glist_namespaces_iterator_type_id, GEE_TYPE_TRAVERSABLE, &gee_traversable_info);
		g_type_add_interface_static (gxml_glist_namespaces_iterator_type_id, GEE_TYPE_ITERATOR, &gee_iterator_info);
		g_type_add_interface_static (gxml_glist_namespaces_iterator_type_id, GEE_TYPE_LIST_ITERATOR, &gee_list_iterator_info);
		g_once_init_leave (&gxml_glist_namespaces_iterator_type_id__volatile, gxml_glist_namespaces_iterator_type_id);
	}
	return gxml_glist_namespaces_iterator_type_id__volatile;
}


static void _vala_gxml_glist_namespaces_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGListNamespacesIterator * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_GLIST_NAMESPACES_TYPE_ITERATOR, GXmlGListNamespacesIterator);
	switch (property_id) {
		case GXML_GLIST_NAMESPACES_ITERATOR_READ_ONLY:
		g_value_set_boolean (value, gee_iterator_get_read_only ((GeeIterator*) self));
		break;
		case GXML_GLIST_NAMESPACES_ITERATOR_VALID:
		g_value_set_boolean (value, gee_iterator_get_valid ((GeeIterator*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void gxml_glist_namespaces_class_init (GXmlGListNamespacesClass * klass) {
	gxml_glist_namespaces_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (GXmlGListNamespacesPrivate));
	((GeeAbstractListClass *) klass)->get = (gpointer (*)(GeeAbstractList*, gint)) gxml_glist_namespaces_real_get;
	((GeeAbstractListClass *) klass)->index_of = (gint (*)(GeeAbstractList*, gconstpointer)) gxml_glist_namespaces_real_index_of;
	((GeeAbstractListClass *) klass)->insert = (void (*)(GeeAbstractList*, gint, gconstpointer)) gxml_glist_namespaces_real_insert;
	((GeeAbstractListClass *) klass)->list_iterator = (GeeListIterator* (*)(GeeAbstractList*)) gxml_glist_namespaces_real_list_iterator;
	((GeeAbstractListClass *) klass)->remove_at = (gpointer (*)(GeeAbstractList*, gint)) gxml_glist_namespaces_real_remove_at;
	((GeeAbstractListClass *) klass)->set = (void (*)(GeeAbstractList*, gint, gconstpointer)) gxml_glist_namespaces_real_set;
	((GeeAbstractListClass *) klass)->slice = (GeeList* (*)(GeeAbstractList*, gint, gint)) gxml_glist_namespaces_real_slice;
	((GeeAbstractCollectionClass *) klass)->add = (gboolean (*)(GeeAbstractCollection*, gconstpointer)) gxml_glist_namespaces_real_add;
	((GeeAbstractCollectionClass *) klass)->clear = (void (*)(GeeAbstractCollection*)) gxml_glist_namespaces_real_clear;
	((GeeAbstractCollectionClass *) klass)->contains = (gboolean (*)(GeeAbstractCollection*, gconstpointer)) gxml_glist_namespaces_real_contains;
	((GeeAbstractCollectionClass *) klass)->iterator = (GeeIterator* (*)(GeeAbstractCollection*)) gxml_glist_namespaces_real_iterator;
	((GeeAbstractCollectionClass *) klass)->remove = (gboolean (*)(GeeAbstractCollection*, gconstpointer)) gxml_glist_namespaces_real_remove;
	GEE_ABSTRACT_COLLECTION_CLASS (klass)->get_read_only = gxml_glist_namespaces_real_get_read_only;
	GEE_ABSTRACT_COLLECTION_CLASS (klass)->get_size = gxml_glist_namespaces_real_get_size;
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_glist_namespaces_get_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_glist_namespaces_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GLIST_NAMESPACES_READ_ONLY, g_param_spec_boolean ("read-only", "read-only", "read-only", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GLIST_NAMESPACES_SIZE, g_param_spec_int ("size", "size", "size", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
}


static void gxml_glist_namespaces_instance_init (GXmlGListNamespaces * self) {
	self->priv = GXML_GLIST_NAMESPACES_GET_PRIVATE (self);
}


static void gxml_glist_namespaces_finalize (GObject* obj) {
	GXmlGListNamespaces * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GLIST_NAMESPACES, GXmlGListNamespaces);
	_g_object_unref0 (self->priv->_doc);
	G_OBJECT_CLASS (gxml_glist_namespaces_parent_class)->finalize (obj);
}


/**
 * A {@link Gee.AbstractList} implementation to access {@link Xml.Ns} namespaces collection
 */
GType gxml_glist_namespaces_get_type (void) {
	static volatile gsize gxml_glist_namespaces_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_glist_namespaces_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGListNamespacesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_glist_namespaces_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGListNamespaces), 0, (GInstanceInitFunc) gxml_glist_namespaces_instance_init, NULL };
		GType gxml_glist_namespaces_type_id;
		gxml_glist_namespaces_type_id = g_type_register_static (GEE_TYPE_ABSTRACT_LIST, "GXmlGListNamespaces", &g_define_type_info, 0);
		g_once_init_leave (&gxml_glist_namespaces_type_id__volatile, gxml_glist_namespaces_type_id);
	}
	return gxml_glist_namespaces_type_id__volatile;
}


static void _vala_gxml_glist_namespaces_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGListNamespaces * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GLIST_NAMESPACES, GXmlGListNamespaces);
	switch (property_id) {
		case GXML_GLIST_NAMESPACES_READ_ONLY:
		g_value_set_boolean (value, gee_abstract_collection_get_read_only ((GeeAbstractCollection*) self));
		break;
		case GXML_GLIST_NAMESPACES_SIZE:
		g_value_set_int (value, gee_abstract_collection_get_size ((GeeAbstractCollection*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}



